@@ -1305,7 +1305,7 @@ static int sc_conn_recv(struct stconn *sc)
 			/* the pipe is full or we have read enough data that it
 			 * could soon be full. Let's stop before needing to poll.
 			 */
-			sc_need_room(sc, 0);
+			sc_need_room(sc, -1);
 			goto done_recv;
 		}
 
@@ -1586,6 +1586,8 @@ static int sc_conn_send(struct stconn *sc)
 		if (sc->state < SC_ST_CON)
 			return 0;
 		BUG_ON(sc_ep_test(sc, SE_FL_EOS|SE_FL_ERROR|SE_FL_ERR_PENDING) == (SE_FL_EOS|SE_FL_ERR_PENDING));
+		if (sc_ep_test(sc, SE_FL_ERROR))
+			sc->flags |= SC_FL_ERROR;
 		return 1;
 	}
 
@@ -1606,7 +1608,7 @@ static int sc_conn_send(struct stconn *sc)
 		if (ret > 0)
 			did_send = 1;
 
-		if (!oc->pipe->data) {
+		if (!oc->pipe->data || sc_ep_test(sc, SE_FL_ERROR | SE_FL_ERR_PENDING)) {
 			put_pipe(oc->pipe);
 			oc->pipe = NULL;
 		}
